/******* Do not edit this file *******
Simple Custom CSS and JS - by Silkypress.com
Saved: Mar 04 2024 | 09:18:55 */
// Get references to the input fields by name
const cf7ppPriceInput = document.querySelector('input[name="cf7pp_price"]');
const productAmountInput = document.querySelector('input[name="Productamount"]');

// Add an event listener to the cf7pp_price input field
cf7ppPriceInput.addEventListener('input', function() {
    // Update the value of the Productamount input field
    productAmountInput.value = this.value;
});